@@ -178,7 +178,7 @@ application = get_wsgi_application()
 
 def VIEWS(app):
     endpoints = app['endpoints']
-    defs = ["import json\nfrom django.http import JsonResponse\nfrom .models import *"]
+    defs = ["import json\nfrom django.http import JsonResponse\nfrom django.views.decorators.csrf import csrf_exempt\n\nfrom .models import *"]
 
     for endpoint in endpoints:
         misc = endpoint['misc']
@@ -186,7 +186,9 @@ def VIEWS(app):
         response = endpoint.get('response')
         responses = ''.join([f'"{k}": "{v}",' for k, v in response.items()])
         csrf = '@csrf_exempt\n' if req.get('host') == 'localhost' else ''
-        body_code = '\n\t\t\tbody = json.loads(request.body)'
+        header_code = '\n\t\t\theaders = request.headers' if len(endpoint.get('headers').get('body').items()) > 0 else ''
+        param_code = '\n\t\t\tparams = kwargs.items()' if len(endpoint.get('params').items()) > 0 else ''
+        body_code = '\n\t\t\tbody = json.loads(request.body)\n\n' if len(endpoint.get('body').get('payload')) > 0 else '\n' if header_code != '' else ''
 
         defs.append(f"""
 # Name: {endpoint.get('misc').get('name')}
@@ -195,11 +197,7 @@ def VIEWS(app):
 # Body: {', '.join([payload[0]+'('+payload[1]+')' for payload in endpoint.get('body').get('payload').values() if payload[0] and payload[1]])}
 {csrf}def {misc.get('token')}(request, *args, **kwargs):
 \tif request.method == '{req.get('method')}':
-\t\ttry:
-\t\t\theaders = request.headers
-{body_code if endpoint.get('body').get('type') == 'json' else ''}
-
-
+\t\ttry:{header_code}{param_code}{body_code}
 \t\t\t#### Add Your Logic Here ####
 
 
@@ -222,39 +220,39 @@ def MODELS(app):
             type = field[2]
             if type == 'UUIDField':
                 _class += f"\t{field[1]} = models.UUIDField(primary_key=True, unique=True, editable=False, max_length=21, default=uuid.uuid4, auto_created=True"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             elif type == 'JSONField':
                 _class += f"\t{field[1]} = models.JSONField(default=dict, null={field[5]}, blank={field[6]}, unique={field[8]}"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             elif type == 'DateTimeField':
                 _class += f"\t{field[1]} = models.DateTimeField(default=timezone.now, null={field[5]}, blank={field[6]}, unique={field[8]}"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             elif type == 'CharField':
                 _class += f"\t{field[1]} = models.CharField(max_length=255, null={field[5]}, blank={field[6]}, unique={field[8]}"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             elif type == 'EmailField':
                 _class += f"\t{field[1]} = models.EmailField(max_length=255, null={field[5]}, blank={field[6]}, unique={field[8]}"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             elif type == 'ImageField':
-                _class += f"\t{field[1]} = models.ImageField(upload_to={field[3]}, null={field[5]}, blank={field[6]}, unique={field[8]}"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f'\t{field[1]} = models.ImageField(upload_to="{field[3]}", null={field[5]}, blank={field[6]}, unique={field[8]}'
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             elif len(type.split('.')) > 1 and type.split('.')[1] == 'id':
-                _class += f"\t{field[1]} = models.ForeignKey({field[2].split('.')[0]}, on_delete=models.SET_NULL, null={field[5]}, blank={field[6]}, unique={field[8]}"
-                _class += f', default={field[3]})' if field[3] else ')'
-                _class += f', verbose={field[4]})' if field[4] else ')'
-                _class += '\n'
+                _class += f"\t{field[1]} = models.ForeignKey(to={field[2].split('.')[0]}, on_delete=models.SET_NULL, null={field[5]}, blank={field[6]}, unique={field[8]}"
+                _class += f', default="{field[3]}"' if field[3] else ''
+                _class += f', verbose="{field[4]}"' if field[4] else ''
+                _class += ')\n'
             else:
                 _class += f"\t{field[1]} = models.{type}(null={field[5]}, blank={field[6]}, unique={field[8]})\n"
 
